@@ -378,6 +378,7 @@ class Twitch(object):
                                                 extra={
                                                     "event": Events.DROP_STATUS,
                                                     "skip_telegram": True,
+                                                    "skip_discord": True,
                                                 },
                                             )
 
@@ -387,6 +388,12 @@ class Twitch(object):
                                                 Events.DROP_STATUS,
                                             )
 
+                                        if Settings.logger.discord is not None:
+                                            Settings.logger.discord.send(
+                                                "\n".join(drop_messages),
+                                                Events.DROP_STATUS,
+                                            )
+
                     except requests.exceptions.ConnectionError as e:
                         logger.error(f"Error while trying to send minute watched: {e}")
                         self.__check_connection_handler(chunk_size)
