@@ -5,7 +5,7 @@ import time
 from datetime import datetime
 from threading import Lock
 
-from TwitchChannelPointsMiner.classes.Chat import ThreadChat
+from TwitchChannelPointsMiner.classes.Chat import ChatPresence, ThreadChat
 from TwitchChannelPointsMiner.classes.entities.Bet import BetSettings, DelayMode
 from TwitchChannelPointsMiner.classes.entities.Stream import Stream
 from TwitchChannelPointsMiner.classes.Settings import Events, Settings
@@ -22,7 +22,7 @@ class StreamerSettings(object):
         "claim_drops",
         "watch_streak",
         "bet",
-        "join_chat",
+        "chat",
     ]
 
     def __init__(
@@ -32,14 +32,14 @@ class StreamerSettings(object):
         claim_drops: bool = None,
         watch_streak: bool = None,
         bet: BetSettings = None,
-        join_chat: bool = True,
+        chat: ChatPresence = None,
     ):
         self.make_predictions = make_predictions
         self.follow_raid = follow_raid
         self.claim_drops = claim_drops
         self.watch_streak = watch_streak
         self.bet = bet
-        self.join_chat = join_chat
+        self.chat = chat
 
     def default(self):
         for name in [
@@ -47,15 +47,16 @@ class StreamerSettings(object):
             "follow_raid",
             "claim_drops",
             "watch_streak",
-            "join_chat",
         ]:
             if getattr(self, name) is None:
                 setattr(self, name, True)
         if self.bet is None:
             self.bet = BetSettings()
+        if self.chat is None:
+            self.chat = ChatPresence.ONLINE
 
     def __repr__(self):
-        return f"BetSettings(make_predictions={self.make_predictions}, follow_raid={self.follow_raid}, claim_drops={self.claim_drops}, watch_streak={self.watch_streak}, bet={self.bet}, join_chat={self.join_chat})"
+        return f"BetSettings(make_predictions={self.make_predictions}, follow_raid={self.follow_raid}, claim_drops={self.claim_drops}, watch_streak={self.watch_streak}, bet={self.bet}, chat={self.chat})"
 
 
 class Streamer(object):
@@ -116,7 +117,8 @@ class Streamer(object):
         if self.is_online is True:
             self.offline_at = time.time()
             self.is_online = False
-            self.leave_chat()
+
+        self.toggle_chat()
 
         logger.info(
             f"{self} is Offline!",
@@ -131,7 +133,8 @@ class Streamer(object):
             self.online_at = time.time()
             self.is_online = True
             self.stream.init_watch_streak()
-            self.join_chat()
+
+        self.toggle_chat()
 
         logger.info(
             f"{self} is Online!",
@@ -220,7 +223,6 @@ class Streamer(object):
 
     def __save_json(self, key, data={}, event_type="Watch"):
         # https://stackoverflow.com/questions/4676195/why-do-i-need-to-multiply-unix-timestamps-by-1000-in-javascript
-        # data.update({"x": round(time.time() * 1000)})
         now = datetime.now().replace(microsecond=0)
         data.update({"x": round(datetime.timestamp(now) * 1000)})
 
@@ -250,6 +252,22 @@ class Streamer(object):
                 self.username,
             )
 
-    def join_chat(self):
+    def __join_chat(self):
         if self.irc_chat is not None:
-            self.irc_chat.start()
+            if self.irc_chat.is_alive() is False:
+                self.irc_chat.start()
+
+    def toggle_chat(self):
+        if self.settings.chat == ChatPresence.ALWAYS:
+            self.__join_chat()
+        elif self.settings.chat != ChatPresence.NEVER:
+            if self.is_online is True:
+                if self.settings.chat == ChatPresence.ONLINE:
+                    self.__join_chat()
+                elif self.settings.chat == ChatPresence.OFFLINE:
+                    self.leave_chat()
+            else:
+                if self.settings.chat == ChatPresence.ONLINE:
+                    self.leave_chat()
+                elif self.settings.chat == ChatPresence.OFFLINE:
+                    self.__join_chat()
